summaryrefslogtreecommitdiffstats
path: root/tdeio/tdeio/krun.cpp
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-09-03 20:02:30 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-09-03 21:00:39 +0200
commitc6cb3f27942501d24b0ded69c90ebbf7c43c755e (patch)
tree08aa592dea84d77931478751d69b47cb4d6b50ee /tdeio/tdeio/krun.cpp
parentf41d2ce0f1929574f3b65eef2675ac65177608f1 (diff)
downloadtdelibs-c6cb3f27942501d24b0ded69c90ebbf7c43c755e.tar.gz
tdelibs-c6cb3f27942501d24b0ded69c90ebbf7c43c755e.zip
Additional k => tde renaming and fixes
Diffstat (limited to 'tdeio/tdeio/krun.cpp')
-rw-r--r--tdeio/tdeio/krun.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/tdeio/tdeio/krun.cpp b/tdeio/tdeio/krun.cpp
index d92e3ca11..ccb638288 100644
--- a/tdeio/tdeio/krun.cpp
+++ b/tdeio/tdeio/krun.cpp
@@ -697,7 +697,7 @@ static pid_t runTempService( const KService& _service, const KURL::List& _urls,
static KURL::List resolveURLs( const KURL::List& _urls, const KService& _service )
{
// Check which protocols the application supports.
// This can be a list of actual protocol names, or just KIO for KDE apps.
TQStringList supportedProtocols = _service.property("X-TDE-Protocols").toStringList();
KRunMX1 mx1( _service );
TQString exec = _service.exec();
@@ -706,10 +706,10 @@ static KURL::List resolveURLs( const KURL::List& _urls, const KService& _service
} else {
if ( supportedProtocols.isEmpty() )
{
// compat mode: assume KIO if not set and it's a KDE app
TQStringList categories = _service.property("Categories").toStringList();
if (( categories.find("TDE") != categories.end() ) && ( categories.find("KDE") != categories.end() ))
- supportedProtocols.append( "KIO" );
+ supportedProtocols.append( "TDEIO" );
else { // if no KDE app, be a bit over-generic
supportedProtocols.append( "http");
supportedProtocols.append( "ftp");
@@ -719,7 +719,7 @@ static KURL::List resolveURLs( const KURL::List& _urls, const KService& _service
kdDebug(7010) << "supportedProtocols:" << supportedProtocols << endl;
KURL::List urls( _urls );
- if ( supportedProtocols.find( "KIO" ) == supportedProtocols.end() ) {
+ if ( supportedProtocols.find( "TDEIO" ) == supportedProtocols.end() ) {
for( KURL::List::Iterator it = urls.begin(); it != urls.end(); ++it ) {
const KURL url = *it;
bool supported = url.isLocalFile() || supportedProtocols.find( url.protocol().lower() ) != supportedProtocols.end();
@@ -1155,7 +1155,7 @@ void KRun::scanFile()
}
// No mimetype found, and the URL is not local (or fast mode not allowed).
// We need to apply the 'KIO' method, i.e. either asking the server or
// getting some data out of the file, to know what mimetype it is.
if ( !KProtocolInfo::supportsReading( m_strURL ) )
@@ -1311,7 +1311,7 @@ void KRun::foundMimeType( const TQString& type )
/*
// Automatically unzip stuff
// Disabled since the new KIO doesn't have filters yet.
if ( type == "application/x-gzip" ||
type == "application/x-bzip" ||
@@ -697,7 +697,7 @@ static pid_t runTempService( const KService& _service, const KURL::List& _urls,
{
// Check which protocols the application supports.
- // This can be a list of actual protocol names, or just KIO for KDE apps.
+ // This can be a list of actual protocol names, or just TDEIO for KDE apps.
TQStringList supportedProtocols = _service.property("X-TDE-Protocols").toStringList();
KRunMX1 mx1( _service );
@@ -706,10 +706,10 @@ static KURL::List resolveURLs( const KURL::List& _urls, const KService& _service
if ( supportedProtocols.isEmpty() )
{
- // compat mode: assume KIO if not set and it's a KDE app
+ // compat mode: assume TDEIO if not set and it's a KDE app
TQStringList categories = _service.property("Categories").toStringList();
if (( categories.find("TDE") != categories.end() ) && ( categories.find("KDE") != categories.end() ))
@@ -1155,7 +1155,7 @@ void KRun::scanFile()
}
// No mimetype found, and the URL is not local (or fast mode not allowed).
- // We need to apply the 'KIO' method, i.e. either asking the server or
+ // We need to apply the 'TDEIO' method, i.e. either asking the server or
// getting some data out of the file, to know what mimetype it is.
if ( !KProtocolInfo::supportsReading( m_strURL ) )
@@ -1311,7 +1311,7 @@ void KRun::foundMimeType( const TQString& type )
/*
// Automatically unzip stuff
- // Disabled since the new KIO doesn't have filters yet.
+ // Disabled since the new TDEIO doesn't have filters yet.
if ( type == "application/x-gzip" ||
type == "application/x-bzip" ||